AdaptiveFormFieldStyle class abstract

Implementers

Constructors

AdaptiveFormFieldStyle({required double cornerRadius, required double borderWidth, required Color borderColor, required Color fillColor, required EdgeInsetsGeometry padding, required TextStyle textStyle, required TextStyle hintStyle, required Color cursorColor})
const

Properties

borderColor Color
final
borderWidth double
final
cornerRadius double
final
cursorColor Color
final
fillColor Color
final
hashCode int
The hash code for this object.
no setterinherited
hintStyle TextStyle
final
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited