AndroidFormFieldStyle class
- Inheritance
-
- Object
- AdaptiveFormFieldStyle
- AndroidFormFieldStyle
Constructors
- AndroidFormFieldStyle()
-
const
Properties
- borderColor → Color
-
finalinherited
- borderWidth → double
-
finalinherited
- cornerRadius → double
-
finalinherited
- cursorColor → Color
-
finalinherited
- fillColor → Color
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle
-
finalinherited
- padding → EdgeInsetsGeometry
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited